#include  <signal.h>
#include  <io.h>
#include <iomacros.h>
#include <stdlib.h>
#include "lcd.h"
#include "i2chw.h"


/* Bit setzen */
#define set_bit(var, bit) ((var) |= (1 << (bit)))
/* Bit lschen */
#define clear_bit(var, bit) ((var) &= (unsigned)~(1 << (bit)))
// Bit abfragen ==> gibts in der neuen Lib

#define bit_is_set(var, bit) ((var) & (1 << (bit)))
#define bit_is_clear(var, bit) !bit_is_set(var, bit)


#define SLAVE1 0x48       //LM75 A0-A2 auf Masse


/*
** function prototypes
*/ 
void wait_until_key_pressed(void);


int main(void){
    
    volatile int16_t i;
    uint16_t temp0;
    uint8_t temp1;
    
         
    WDTCTL = WDTPW + WDTHOLD;                 // Stop WDT
    BCSCTL1 &= ~XT2OFF;                       // XT2= HF XTAL

    do{
       IFG1 &= ~OFIFG;                        // Clear OSCFault flag
       for (i = 0xFF; i > 0; i--);            // Time for flag to set
    }while ((IFG1 & OFIFG));                  // OSCFault flag still set?

    BCSCTL2 |= SELM_2;                        // MCLK= XT2 (safe)
     

    P1DIR=0xF0;            // port 1 = output (4 LED)
    P1OUT=0x0F;  
    P1SEL=0x00;            // alle ports als GPIO nutzen, und nicht als A/D-Wandler oder so ... 
    P1IE=0x00;             // interrupt ausmachen
    P2IE=0x00;             // interrupt ausmachen
    
    
    
     /* initialize display, cursor off */
    lcd_init(LCD_DISP_ON);
    
    i2c_init();
    
    for (;;) {                           /* loop forever */
        /* 
        * Test 1:  write text to display
        */

        /* clear display and home cursor */
        lcd_clrscr();
        
        /* put string to display (line 1) with linefeed */
        lcd_puts("I2C-Test");
        
        i2c_start(SLAVE1);
                
        temp0 = i2c_readAck();
        lcd_puts_int(temp0,0,1);
        
        temp1 = i2c_readAck();
        lcd_puts_int(temp1,0,2);
                               
        /* wait until push button PD2 (INT0) is pressed */
        wait_until_key_pressed();
        
        lcd_clrscr();
        
        wait_until_key_pressed();           
    }
    
    return 0;    
}

void wait_until_key_pressed(void) {

    unsigned char temp1, temp2;
    unsigned int i;
    
    do {
        temp1 = P1IN;                  // read input
        for(i=0;i<65535;i++);
        temp2 = P1IN;                  // read input
        temp1 = (temp1 & temp2);       // debounce input
    } while ( temp1 & (1 << 0) );
    
    do { } while (bit_is_clear(P1IN, 0));
   
}
